"""
pycraigslist.tests.specs
~~~~~~~~~~~~~~~~~~~~~~~~

A suite of modules that stores test data and utility methods.
"""

from tests.specs.static import *
